==> sal-cluster-admin-api-1.9.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/params/xml/ns/yang/controller/md/sal/cluster/admin/rev151013/member/voting/states/input/MemberVotingState.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.controller.md.sal.cluster.admin.rev151013.member.voting.states.input;
import java.lang.Boolean;
import java.lang.String;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.controller.md.sal.cluster.admin.rev151013.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.controller.md.sal.cluster.admin.rev151013.MemberVotingStatesInput;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;

/**
 * The list of member voting states
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>cluster-admin</b>
 * <pre>
 * list member-voting-state {
 *   leaf member-name {
 *     type string;
 *   }
 *   leaf voting {
 *     type boolean;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>cluster-admin/member-voting-states-input/member-voting-state</i>
 *
 * <p>To create instances of this class use {@link MemberVotingStateBuilder}.
 * @see MemberVotingStateBuilder
 *
 *
 */
public interface MemberVotingState
    extends
    ChildOf<MemberVotingStatesInput>,
    Augmentable<MemberVotingState>
{



    public static final QName QNAME = $YangModuleInfoImpl.qnameOf("member-voting-state");

    /**
     * @return <code>java.lang.String</code> <code>memberName</code>, or <code>null</code> if not present
     */
    @Nullable String getMemberName();
    
    /**
     * @return <code>java.lang.Boolean</code> <code>voting</code>, or <code>null</code> if not present
     */
    @Nullable Boolean isVoting();

}

==> sal-cluster-admin-api-1.10.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/params/xml/ns/yang/controller/md/sal/cluster/admin/rev151013/member/voting/states/input/MemberVotingState.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.controller.md.sal.cluster.admin.rev151013.member.voting.states.input;
import java.lang.Boolean;
import java.lang.Class;
import java.lang.Override;
import java.lang.String;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.controller.md.sal.cluster.admin.rev151013.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.controller.md.sal.cluster.admin.rev151013.MemberVotingStatesInput;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;

/**
 * The list of member voting states
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>cluster-admin</b>
 * <pre>
 * list member-voting-state {
 *   leaf member-name {
 *     type string;
 *   }
 *   leaf voting {
 *     type boolean;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>cluster-admin/member-voting-states-input/member-voting-state</i>
 *
 * <p>To create instances of this class use {@link MemberVotingStateBuilder}.
 * @see MemberVotingStateBuilder
 *
 *
 */
public interface MemberVotingState
    extends
    ChildOf<MemberVotingStatesInput>,
    Augmentable<MemberVotingState>
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("member-voting-state");

    @Override
    default Class<org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.controller.md.sal.cluster.admin.rev151013.member.voting.states.input.MemberVotingState> implementedInterface() {
        return org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.controller.md.sal.cluster.admin.rev151013.member.voting.states.input.MemberVotingState.class;
    }
    
    /**
     * @return <code>java.lang.String</code> <code>memberName</code>, or <code>null</code> if not present
     */
    @Nullable String getMemberName();
    
    /**
     * @return <code>java.lang.Boolean</code> <code>voting</code>, or <code>null</code> if not present
     */
    @Nullable Boolean isVoting();

}
